--[[

TITLE:		LfgGabStopper

AUTHOR:		Landru

DESCRIPTION:	Filters out non-"looking for group" messages from the
		"LookingForGroup" channel.

USAGE:		Use the command "/lfggabstopper" to toggle the filter on and off,
		or (better yet) bind the filter to a key (using the key-binding
		menu) for more convenient toggling.

NOTES:		This mod is built from the mod "PVPNoSpam" by Grayhoof and changes
		very little of the underlying structure and naming conventions of
		that mod.
]]--

-- The Everlasting Gab Stopper:  more LFG, Less F*cking Gab!!! --

--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\
--\\  VARIABLES

LFGGABSTOPPER_bEnabled		= true;		--\\ whether filter enabled or not (global)
local Original_ChatFrame_OnEvent;		--\\ stores original/normal chat message handler

--\\ constants for controlling output message format
local LFGGABSTOPPER_COLOR_GREEN	= "|cff00ff00";
local LFGGABSTOPPER_COLOR_RED	= "|cffff0000";
local LFGGABSTOPPER_COLOR_CYAN	= "|cff00ffff";
local LFGGABSTOPPER_STATUS_ON	= LFGGABSTOPPER_COLOR_CYAN.."LfgGabStopper:"..LFGGABSTOPPER_COLOR_GREEN.."  Filter is -ON-.|r";
local LFGGABSTOPPER_STATUS_OFF	= LFGGABSTOPPER_COLOR_CYAN.."LfgGabStopper:"..LFGGABSTOPPER_COLOR_RED..  "  Filter is -OFF-.|r";

--\\ the key-binding menu; put in localization.lua if you want to adapt this mod for
--\\ different languages (will also need to change what the filter screens out)
BINDING_HEADER_LFGGABSTOPPER	= "LFG Gab Stopper"
BINDING_NAME_LFGGABSTOPPER	= "Toggle LFG anti-chat filter"

--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\
--\\  LOCAL METHODS

--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_Status()
	if (DEFAULT_CHAT_FRAME) then
		if (LFGGABSTOPPER_bEnabled) then
			LFGGABSTOPPER_Status_AllLfgFrames(LFGGABSTOPPER_STATUS_ON);
		else
			LFGGABSTOPPER_Status_AllLfgFrames(LFGGABSTOPPER_STATUS_OFF);
		end
	end
end

--\\ dump given message to all chat frames that have LFG channel enabled, and
--\\ also dump to the default channel
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_Status_AllLfgFrames(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg);
	for i=1,20 do				--\\ 20 is arbitrary; seems large enough...
		local cf=getglobal("ChatFrame"..i);
		if (not cf) then return; end	--\\ stop trying when we run out of chat frames
		if (cf:GetID() ~= DEFAULT_CHAT_FRAME:GetID()) then
			--\\ determine if cf has LFG channel enabled; if so, output msg
			local chns = { GetChatWindowChannels(cf:GetID()) }
			for k,v in pairs(chns) do
				if (v=="LookingForGroup") then
					cf:AddMessage(msg);
					break;
				end
			end
		end
	end
end

--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_ToggleStatus(msg)
	LFGGABSTOPPER_bEnabled = not LFGGABSTOPPER_bEnabled;
	LFGGABSTOPPER_Status();
end

--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
--\\
--\\  SYSTEM METHODS

--\\ called when mod loaded
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_OnLoad()
	this:RegisterEvent("ADDON_LOADED");

	--\\ add slash commands
	SlashCmdList["LFGGABSTOPPER"] = LFGGABSTOPPER_ToggleStatus;
	SLASH_LFGGABSTOPPER1 = "/lfggabstopper";

	--\\ hook into system message handler
	Original_ChatFrame_OnEvent = ChatFrame_OnEvent;
	ChatFrame_OnEvent = LFGGABSTOPPER_ChatFrame_OnEvent;

	--\\ announce ourselves
	LFGGABSTOPPER_Status();
end

--\\ event handler
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_OnEvent()
	if ( event == "ADDON_LOADED" and strlower(arg1) == "lfgchatblocker" ) then
		LFGGABSTOPPER_Status();
	end
end

--\\ hook function
--\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
function LFGGABSTOPPER_ChatFrame_OnEvent(event)

	--\\ if filter disabled, process messages as normal
	if (not LFGGABSTOPPER_bEnabled) then Original_ChatFrame_OnEvent(event); return; end

	--\\ only want to process chat messages sent to "LookingForGroup" channel
	if (not arg4) or (not strfind(tostring(arg4), "LookingForGroup")) then
	   Original_ChatFrame_OnEvent(event);
	   return;
	end

	--\\ arg1 contains message text(?); use it to screen for true LFG messages
	if (not arg1) then Original_ChatFrame_OnEvent(event); return; end

	--\\ we could screen by instance abbreviations, but that would require more searches
	--\\ than the solution below; the first search alone is good enough for most true LFG
	--\\ messages, so remove the others if running too slowly
	ls=tostring(arg1);
	if (	strfind(ls, "LF")		or
		strfind(ls, "lfg")		or
		strfind(ls, "lfm")		or
		strfind(strsub(ls,1,3), "lf ")	or
		strfind(ls, " lf")		or
		strfind(ls, "lf1")		or
		strfind(ls, "lf2")		or
		strfind(ls, "lf3")		or
		strfind(ls, "lf4")		)
	then
		Original_ChatFrame_OnEvent(event);
	end
end
